@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 #
-# $Id: tpopedataclick.pl,v 1.2 2008-09-03 18:46:02 cvscore Exp $
+# $Id: tpopedataclick.pl,v 1.3 2008-09-21 23:30:08 cvscore Exp $
 
 use strict;
 use WebService::Eulerian::Analytics::Website;
@@ -13,6 +13,7 @@ my %h_api_params	= (
 
 my $website_name	= 'MY_WEBSITE';	# name of the targeted website
 my $tpope_name		= 'MY_CAMPAIGN';# name of the targeted campaign
+my $tpmedia_name	= 'MY_TPMEDIA';	# name of the targeted tpmedia
 my $date_from		= '01/08/2008';	# timeperiod include all day
 my $date_to		= '02/08/2008';	# timeperiod include all day
 
@@ -24,7 +25,7 @@ my $rh_website	= $website->getByName( $website_name );
 
 die $website->faultstring		if ( $website->fault );
 
-# fetch the log data in Website/TPOpedataClick service
+# fetch the log data in Website/TPOpedataClick service by TPOpe
 my $ra_log	= $tpopedataclick->getLogByTPOpeName($rh_website->{website_id},{
  tpope_name	=> $tpope_name,
  date_from	=> $date_from,
@@ -37,6 +38,19 @@ for ( @{ $ra_log } ) {
  print "date ".localtime($_->{epoch})." | IP : ".$_->{ip}." | Channel Information : level0=".$_->{channel_0}." level1=".$_->{channel_1}." level2=".$_->{channel_2}."\n";
 }
 
+# fetch the log data in Website/TPOpedataClick service by TPMedia
+$ra_log = $tpopedataclick->getLogByTPMediaName($rh_website->{website_id},{
+ tpmedia_name	=> $tpmedia_name,
+ date_from	=> $date_from,
+ date_to	=> $date_to,
+});
+
+die $tpopedataclick->faultstring	if ( $tpopedataclick->fault );
+
+for ( @{ $ra_log } ) {
+ print "date ".localtime($_->{epoch})." | IP : ".$_->{ip}." | Channel Information : level0=".$_->{channel_0}." level1=".$_->{channel_1}." level2=".$_->{channel_2}." | Outbound campaign : ".$_->{tpope_name}."\n";
+}
+
 
 1;
 __END__
